#
# spec file for package IPAddress
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           IPAddress
Version:        5.5.1
Release:        1.5
Summary:        Library for handling IP addresses and subnets, both IPv4 and IPv6
License:        Apache-2.0
URL:            https://github.com/seancfoley/IPAddress
Source0:        https://github.com/seancfoley/IPAddress/archive/v%{version}.tar.gz
Patch0:         IPAddress-encoding.patch
Patch1:         IPAddress-doclet.patch
BuildRequires:  ant
BuildRequires:  aqute-bnd
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch

%description
Library for handling IP addresses and subnets, both IPv4 and IPv6

%package        javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description    javadoc
This package provides API documentation for xbean.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
find -name \*.jar -delete
find -name \*.class -delete

echo "-reproducible: true" >> IPAddress/ipaddress.bnd
echo "-noextraheaders: true" >> IPAddress/ipaddress.bnd
echo "-snapshot: SNAPSHOT" >> IPAddress/ipaddress.bnd

%build
pushd IPAddress
mkdir bin
%{ant} "create dist jar" "create javadoc" "create pom"

%install
# jar
install -dm 755 %{buildroot}%{_javadir}
install -m 0644 IPAddress/dist/IPAddress*.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} IPAddress/dist/mavenlib/pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

# javadoc
install -dm 755 %{buildroot}/%{_javadocdir}/%{name}
cp -a IPAddress/javadoc/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE
%doc README.md

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Thu Nov  7 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 5.5.1
  * Fixes of 5.3.4:
    + a fix to avoid ClassCastException when converting IPv4-mapped
    address to java.net.Inet6Address (#73)
    + fixed the creation of HostName from an unresolved
    compressed-IPv6 socket address (#74)
    + added IPAddressString.isIPv4Mapped for issue #75
    + fixed a class-loading issue with string parsing (#79)
    + removed AddressDivision.getDivisionValueCount() and
    AddressDivision.getDivisionPrefixCount(int) because of
    potential overflow with divisions 63 or 64 bits long. If you
    have a segment, use getValueCount(), or with IPAddressSegment
    use getPrefixValueCount(int), which both return int.
    Otherwise, use getPrefixCount(int) or getCount() which return
    BigInteger
    + fixed issues with comparing non-standard division groupings
    with address comparators
    + added verification when host-masking multiple-valued segments
    + added verification when splitting IPv6AddressSegment
    + fixed check when reversing per-byte multiple-valued division
    + fixed trie-printing method option withNonAddedKeys
    + fixed an issue with serialization of parsed hosts with
    qualifiers
    + added control over parsing empty zones (a zone specifier
    followed by no zone)
    + added a small fix to host name parsing some unusual host names
    + a fix to IPv4AddressSection.toMaxHost
    + fixed a rare synchronization issue when generating division
    strings in AddressDivisionBase
  * Fixes of 5.4.0:
    + added PrefixBlockAllocator for automatic CIDR prefix block
    allocation
    + added AddedTree and AssociativeAddedTree classes for expanded
    constructAddedNodesTree methods
    + added getBlockSize and getBitsForCount in AddressItem
    + added matchUnordered and matchOrdered in Address
    + eliminated invalid AddressValueException when joining a range
    with the IPv4 max value to an IPv6 range (#86)
    + fix to generation of strings from parsed address data (#87)
    + fix to IPv4 address primitive int upper value generation (#96)
  * Fix of 5.4.1:
    + fix to invalid radix argument infinite loop
    (#118, CVE-2023-50570)
  * Fixes of 5.4.2:
    + removed unnecessary SDK dependency incompatible with Java 8
    that was introduced with version 5.4.1 (#121)
  * Fixes of 5.5.0:
    + added collection types for dual IPv4/v6 tries and for dual
    IPv4/v6 associative tries, issue #103
    + trie performance improvements for all trie operations
    + added shortestPrefixMatch trie methods
    + added enumerate methods, the inverse of the increment methods,
    to find the position of an address in a subnet, or to find
    the distance between two addresses
    + added an increment method accepting a BigInteger argument to
    IPv6Address and IPv6AddressSection
    + added the ability to construct an IPv6Address from two longs
    + added replace methods with address section parameter to
    address classes
    + added overlaps methods to check for overlapping subnets, and
    for checking sequential range overlap with a subnet
    + added floor/lower/ceiling/higher methods to the address trie
    types, these methods previously accessible only from trie sets
    + added the extraneous digits IPv4 parsing option
    allow_inet_aton_extraneous_digits (#105)
  * Fixes of 5.5.1:
    + added new merge functions mergeToDualPrefixBlocks and
    mergeToDualSequentialBlocks for combined IPv4/IPv6 merging
    + added public constructors accepting message strings to
    AddressValueException and IncompatibleAddressException (#127)
    + removed caching functionality from containingFirstIterator,
    use all-node containingFirstAllNodeIterator instead
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep 13 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: produce reproducible manifest with bnd
* Mon Mar  7 2022 Fridrich Strba <fstrba@suse.com>
- Initial packaging of IPAddress 5.3.3
